@@ -726,15 +726,11 @@ class EditorDialogBase(object):
                 os.mkdir(self.savedir)
             except OSError, e:
                 pass
-        # If filename is None, then it is a new file, and we will open
-        # the folder in the users home dir.
-        # If the file already have a file name, we will open the folder
-        # containing the file.
-        if not self.m_filename or os.path.isabs(self._get_a_filename()):
-            dialog.set_current_folder(self.savedir)
+        if self.m_filename and os.path.commonprefix([
+               self.savedir, os.path.dirname(self.m_filename)]) == self.savedir:
+            dialog.set_current_folder(os.path.dirname(self.m_filename))
         else:
-            dialog.set_current_folder(os.path.dirname(self._get_a_filename()))
-        dialog.set_current_name(os.path.basename(self._get_a_filename()))
+            dialog.set_current_folder(self.savedir)
         while 1:
             ret = dialog.run()
             if ret == gtk.RESPONSE_OK:
@@ -850,13 +846,12 @@ class LogWindow(gtk.Window):
 
 
 class ClickableLabel(gtk.LinkButton):
-    def __init__(self, label, filename=None):
+    def __init__(self, label):
         """
         We are abusing the Link button by not giving it a real uri.
         So let ut not even pretend to follow its api.
         """
-        gtk.LinkButton.__init__(self, label)
-        self.m_filename = filename
+        gtk.LinkButton.__init__(self, label, label)
         self.get_children()[0].set_alignment(0.0, 0.5)
     def make_warning(self):
         im = gtk.Image()
