@@ -49,7 +49,7 @@ _test_mode = False
 
 # The name of the folder containing the standard learning trees.
 # Relative to the installation dir.
-exercises_dir = u"exercises"
+exercises_dir = u"exercises/standard"
 _abs_exercises_dir = os.path.join(os.getcwdu(), exercises_dir) + os.sep
 
 solfege_uri = u"solfege:"
@@ -1538,9 +1538,9 @@ class InfoCache(object):
                 self.parse_file(filename)
             return self._data[filename][field]
         def parse_file(self, filename):
-            from solfege import learningtree
+            from solfege import frontpage 
             try:
-                p = learningtree.load_tree(filename)
+                p = frontpage.load_tree(filename)
                 self._data[filename] = {'title': p.m_name,
                                         'mtime': os.path.getmtime(filename)}
             except Exception, exception:
@@ -1632,7 +1632,10 @@ class InfoCache(object):
         Check the mtime of the files in dir if dirs mtime has changed
         or is not in _data. Parse the lesson files if their mtime has
         changed or is not in _data.
+        Do nothing if the dir does not exist.
         """
+        if not os.path.exists(dir):
+            return
         mtime = os.path.getmtime(dir)
         assert isinstance(dir, unicode)
         logging.debug("cond_parse_dir(%s) mtime=%s" % (dir, mtime))
@@ -1674,10 +1677,10 @@ class LessonFileManager:
         self.m_discards = []
         self.m_uiddb = {}
     def parse(self, debug):
-        lessonpath = [os.path.join('exercises', 'lesson-files'),
+        lessonpath = [os.path.join('exercises', 'standard', 'lesson-files'),
                       filesystem.user_lessonfiles()]
         if debug:
-            lessonpath.append(os.path.join('exercises', 'regression-lesson-files'))
+            lessonpath.append(os.path.join('exercises', 'standard', 'regression-lesson-files'))
         self.m_uiddb = {}
         for dir in lessonpath:
             if not os.path.isdir(dir):
