@@ -408,6 +408,15 @@ class AbstractStatistics(object):
         self.m_t = teacher
         self.m_timestamp = None
         self.m_test_mode = False
+    def int_if_int(self, s):
+        """
+        Return an int if the can be converted to an int.
+        Return unchanged if not.
+        """
+        try:
+            return int(s)
+        except ValueError:
+            return s
     def get_keys(self, all_keys=False):
         """
         Return the keys for all questions that have been answered correctly.
@@ -422,7 +431,9 @@ class AbstractStatistics(object):
             c = solfege.db.conn.execute("select distinct(answerkey) from sessions where fileid=?", (fileid,))
         else:
             c = solfege.db.conn.execute("select distinct(answerkey) from sessions where fileid=? and answerkey=guessed", (fileid,))
-        return [x[0] for x in c]
+        v = [self.int_if_int(x[0]) for x in c]
+        v.sort()
+        return [unicode(x) for x in v]
     def get_statistics(self, seconds):
         """
         return a dict with statistics more recent than 'seconds' seconds.
@@ -443,8 +454,8 @@ class AbstractStatistics(object):
             q = solfege.db.conn.execute("select answerkey, guessed, sum(count) from sessions where fileid=? and timestamp>? group by answerkey, guessed", (fileid, self.m_timestamp - seconds))
         ret = {}
         for answer, guess, count in q.fetchall():
-            ret.setdefault(answer, {})
-            ret[answer][guess] = count
+            ret.setdefault(self.int_if_int(answer), {})
+            ret[self.int_if_int(answer)][self.int_if_int(guess)] = count
         return ret
     def reset_session(self):
         """
@@ -481,7 +492,7 @@ class AbstractStatistics(object):
         row = cursor.execute(
                 "select count from %s where fileid=? and timestamp=? "
                 "and answerkey=? and guessed=?" % table,
-                (fileid, self.m_timestamp, question, answer)).fetchone()
+                (fileid, self.m_timestamp, unicode(question), unicode(answer))).fetchone()
         if not row:
             cursor.execute(
                 "insert into %s "
@@ -495,7 +506,7 @@ class AbstractStatistics(object):
                 "update %s set count=? where "
                 "fileid=? and timestamp=? and answerkey=? and guessed=?" % table,
                 (row[0] + 1, fileid,
-                 self.m_timestamp, question, answer))
+                 self.m_timestamp, unicode(question), unicode(answer)))
         solfege.db.conn.commit()
     def add_wrong(self, question, answer):
         self._add(question, answer)
@@ -507,12 +518,12 @@ class AbstractStatistics(object):
         """
         return solfege.db.last_test_result(self.m_t.m_P.m_filename)
     def get_percentage_correct(self):
-        """Will return a 0 <= value <= 1.0 that say how many percent is
+        """Will return a 0 <= value <= 100.0 that say how many percent is
         correct in this session
         """
-        fileid = solfege
+        fileid = solfege.db.get_fileid(self.m_t.m_P.m_filename)
         num_correct = solfege.db.conn.execute("select sum(count) from sessions where answerkey=guessed and timestamp=? and fileid=?", (self.m_timestamp, fileid)).fetchone()[0]
-        num_asked = solfege.db.conn.execute("select sum(count) from sessions where timestamp=? and  fileid=?", (self.m_timestamp, file)).fetchone()[0]
+        num_asked = solfege.db.conn.execute("select sum(count) from sessions where timestamp=? and  fileid=?", (self.m_timestamp, fileid)).fetchone()[0]
         if not num_correct:
             num_correct = 0
         if not num_asked:
