@@ -2,6 +2,7 @@
 import glob
 import os
 import shutil
+import solfege.languages
 
 sol_po = glob.glob("po/*.po")
 sol_po = [os.path.split(x)[1] for x in sol_po]
@@ -15,7 +16,15 @@ for lang in gtk_po:
 
 shutil.rmtree(r"win32\python\Lib\test")
 shutil.rmtree(r"win32\python\Lib\curses")
-shutil.rmtree(r"win32\etc")
 shutil.rmtree(r"win32\share\applications")
 shutil.rmtree(r"win32\share\man")
-os.remove(r"win32\GTK\uninst.exe")
+shutil.rmtree(r"win32\python\Doc")
+shutil.rmtree(r"win32\python\tcl")
+shutil.rmtree(r"win32\python\Tools")
+shutil.rmtree(r"win32\test")
+shutil.rmtree(r"win32\include")
+shutil.rmtree(r"win32\python\include")
+for fn in glob.glob("win32/share/locale/*"):
+    if not os.path.split(fn)[1] in solfege.languages.languages:
+        shutil.rmtree(fn)
+
